==> datapark-facade-1.2.4-sources.jar: com/bxm/datapark/facade/activity/ActivityReportDto.java <==
package com.bxm.datapark.facade.activity;


import java.io.Serializable;

/**
 * Created by wuwenquan on 2018/6/21.
 */
public class ActivityReportDto implements Serializable {

    @Override
    public String toString() {
        return "ActivityReportDto{" +
                "startTime='" + startTime + '\'' +
                ", endTime='" + endTime + '\'' +
                ", appKeys='" + appKeys + '\'' +
                ", positionIds='" + positionIds + '\'' +
                ", activityIds='" + activityIds + '\'' +
                ", activityType='" + activityType + '\'' +
                ", activityplan='" + activityplan + '\'' +
                ", sortName='" + sortName + '\'' +
                ", sortType='" + sortType + '\'' +
                ", pageNum=" + pageNum +
                ", pageSize=" + pageSize +
                ", times='" + times + '\'' +
                '}';
    }

    public ActivityReportDto() {
    }

    public ActivityReportDto(String startTime, String endTime, String appKeys, String positionIds, String activityIds, String activityType, String activityplan, String sortName, String sortType, Integer pageNum, Integer pageSize,String times) {
        this.startTime = startTime;
        this.endTime = endTime;
        this.appKeys = appKeys;
        this.positionIds = positionIds;
        this.activityIds = activityIds;
        this.activityType = activityType;
        this.activityplan = activityplan;
        this.sortName = sortName;
        this.sortType = sortType;
        this.pageNum = pageNum;
        this.pageSize = pageSize;
        this.times=times;

    }
   private String startTime;

   private String endTime;

   private String appKeys;

   private String  positionIds;

   private String activityIds;



    private String  activityType;

   private String  activityplan;

   private String sortName;

   private String  sortType;

   private  Integer pageNum;

   private  Integer pageSize;

   private  String times;

   private String datetime;

   private String json;

   private Long activityId;

   private String business;

    public String getTimes() {
        return times;
    }

    public void setTimes(String times) {
        this.times = times;
    }

    public String getStartTime() {
        return startTime;
    }


    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getAppKeys() {
        return appKeys;
    }

    public void setAppKeys(String appKeys) {
        this.appKeys = appKeys;
    }

    public String getPositionIds() {
        return positionIds;
    }

    public void setPositionIds(String positionIds) {
        this.positionIds = positionIds;
    }

    public String getActivityplan() {
        return activityplan;
    }

    public void setActivityplan(String activityplan) {
        this.activityplan = activityplan;
    }

    public String getSortName() {
        return sortName;
    }

    public void setSortName(String sortName) {
        this.sortName = sortName;
    }

    public String getSortType() {
        return sortType;
    }

    public void setSortType(String sortType) {
        this.sortType = sortType;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(String activityIds) {
        this.activityIds = activityIds;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public String getDatetime() {
        return datetime;
    }

    public void setDatetime(String datetime) {
        this.datetime = datetime;
    }

    public String getJson() {
        return json;
    }

    public void setJson(String json) {
        this.json = json;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }
}

==> datapark-facade-1.2.22-sources.jar: com/bxm/datapark/facade/activity/ActivityReportDto.java <==
package com.bxm.datapark.facade.activity;


import java.io.Serializable;

/**
 * Created by wuwenquan on 2018/6/21.
 */
public class ActivityReportDto implements Serializable {

    @Override
    public String toString() {
        return "ActivityReportDto{" +
                "startTime='" + startTime + '\'' +
                ", endTime='" + endTime + '\'' +
                ", appKeys='" + appKeys + '\'' +
                ", positionIds='" + positionIds + '\'' +
                ", activityIds='" + activityIds + '\'' +
                ", activityType='" + activityType + '\'' +
                ", activityplan='" + activityplan + '\'' +
                ", sortName='" + sortName + '\'' +
                ", sortType='" + sortType + '\'' +
                ", pageNum=" + pageNum +
                ", pageSize=" + pageSize +
                ", times='" + times + '\'' +
                '}';
    }

    public ActivityReportDto() {
    }

    public ActivityReportDto(String startTime, String endTime, String appKeys, String positionIds, String activityIds, String activityType, String activityplan, String sortName, String sortType, Integer pageNum, Integer pageSize,String times) {
        this.startTime = startTime;
        this.endTime = endTime;
        this.appKeys = appKeys;
        this.positionIds = positionIds;
        this.activityIds = activityIds;
        this.activityType = activityType;
        this.activityplan = activityplan;
        this.sortName = sortName;
        this.sortType = sortType;
        this.pageNum = pageNum;
        this.pageSize = pageSize;
        this.times=times;

    }
   private String startTime;

   private String endTime;

   private String appKeys;

   private String  positionIds;

   private String activityIds;



    private String  activityType;

   private String  activityplan;

   private String sortName;

   private String  sortType;

   private  Integer pageNum;

   private  Integer pageSize;

   private  String times;

   private String  activityTag;

    public String getActivityTag() {
        return activityTag;
    }

    public void setActivityTag(String activityTag) {
        this.activityTag = activityTag;
    }
   private String datetime;

   private String json;

   private Long activityId;

   private String business;

    public String getTimes() {
        return times;
    }

    public void setTimes(String times) {
        this.times = times;
    }

    public String getStartTime() {
        return startTime;
    }


    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getAppKeys() {
        return appKeys;
    }

    public void setAppKeys(String appKeys) {
        this.appKeys = appKeys;
    }

    public String getPositionIds() {
        return positionIds;
    }

    public void setPositionIds(String positionIds) {
        this.positionIds = positionIds;
    }

    public String getActivityplan() {
        return activityplan;
    }

    public void setActivityplan(String activityplan) {
        this.activityplan = activityplan;
    }

    public String getSortName() {
        return sortName;
    }

    public void setSortName(String sortName) {
        this.sortName = sortName;
    }

    public String getSortType() {
        return sortType;
    }

    public void setSortType(String sortType) {
        this.sortType = sortType;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public String getActivityIds() {
        return activityIds;
    }

    public void setActivityIds(String activityIds) {
        this.activityIds = activityIds;
    }

    public String getActivityType() {
        return activityType;
    }

    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    public String getDatetime() {
        return datetime;
    }

    public void setDatetime(String datetime) {
        this.datetime = datetime;
    }

    public String getJson() {
        return json;
    }

    public void setJson(String json) {
        this.json = json;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }
}
